from django.core.management.base import BaseCommand, CommandError
from logement.models import Logement, LogementPhoto, TYPES_LOGEMENTS
from datetime import datetime
from io import BytesIO
from time import sleep
from PIL import Image
import requests
import random

URL_UNSPLASH = "https://source.unsplash.com/random"
# URL_UNSPLASH = "https://source.unsplash.com/collection/47454235"


class Command(BaseCommand):
    help = "Génère des annonces de logements fictives pour tester le service"

    def add_arguments(self, parser):
        parser.add_argument(
            "-i",
            "--iterations",
            type=int,
            default=10,
            help="Le nombre d'annonces à générer",
        )

    def handle(self, *args, **options):
        for i in range(options["iterations"]):

            img = Image.open(requests.get(URL_UNSPLASH, stream=True).raw)
            rawfile = BytesIO()
            img.convert("RGB").save(rawfile, format="jpeg")

            logement = Logement.objects.create(
                typel=random.choice(TYPES_LOGEMENTS)[0],
                surface=random.randint(10, 100),
                loyer=random.randint(100, 1000),
                montant_charges=i,
                montant_caution=random.randint(100, 1000),
                meuble=random.randint(0, 1),
                place_parking=random.randint(0, 1),
                free_date=datetime.today(),
                pub_date=datetime.today(),
                adresse="69 rue du Test, 31071 Toulouse",
                description="Logement de test n°" + str(i),
                nb_obsolete=0,
            )

            annonce = LogementPhoto.objects.create(logement=logement)
            annonce.photo.save(str(random.random()), rawfile)

            rawfile.close()
            img.close()

            print(f"Logement n°{i:d} généré")
